@@ -25,7 +25,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.09;
+    our $VERSION = 1.11;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -63,47 +63,23 @@ Debug::Easy - A Handy Debugging Module With Colorized Output and Formatting
 
  my $debug = Debug::Easy->new( 'LogLevel' => 'DEBUG', 'Color' => 1 );
 
- # $debug_level is the maximum level to report, and ignore the rest.
- # It must be the first parameter passed to the object, when outputing
- # a specific message.  This identifies to the module what type of
- # message it is.
- #
- # The following is a list, in order of level, of the parameter to
- # pass to the debug method:
- #
- #  ERR       = Error
- #  WARN      = Warning
- #  NOTICE    = Notice
- #  INFO      = Information
- #  VERBOSE   = Special version of INFO that does not output any
- #              Logging headings.  Very useful for verbose modes in your
- #              scripts.
- #  DEBUG     = Level 1 Debugging messages
- #  DEBUGMAX  = Level 2 Debugging messages (typically more terse)
- #
- # The third parameter is either a string or a reference to an array
- # of strings to output as multiple lines.
- #
- # Each string can contain newlines, which will also be split into
- # a separate line and formatted accordingly.
- #
- # NOTICE:  Older versions would use a Data::Dumper library to output
- # references automatically.  These libraries slow down script
- # initialization, and thus I removed the capability.  So, if you want
- # Dumper output, youi must load it yourself and use Dumper in the call
+'LogLevel' is the maximum level to report, and ignore the rest.  The method names correspond to their loglevels, when outputting a specific message.  This identifies to the module what type of message it is.
 
- my $debug_level = 'NOTICE';
+The following is a list, in order of level, of the logging methods:
 
- $debug->debug($debug_level,"Message");
+ ERR       = Error
+ WARN      = Warning
+ NOTICE    = Notice
+ INFO      = Information
+ VERBOSE   = Special version of INFO that does not output any
+             Logging headings.  Very useful for verbose modes in your
+             scripts.
+ DEBUG     = Level 1 Debugging messages
+ DEBUGMAX  = Level 2 Debugging messages (typically more terse)
 
- $debug->debug('ERR',      ['Error message']);
- $debug->debug('WARN',     ['Warning message']);
- $debug->debug('NOTICE',   ['Notice message']);
- $debug->debug('INFO',     ['Information and VERBOSE mode message']);
- $debug->debug('DEBUG',    ['Level 1 Debug message']);
- $debug->debug('DEBUGMAX', ['Level 2 Debug message']);
+The parameter is either a string or a reference to an array of strings to output as multiple lines.
 
- # Or...
+Each string can contain newlines, which will also be split into a separate line and formatted accordingly.
 
  $debug->ERR(        ['Error message']);
  $debug->ERROR(      ['Error message']);
@@ -113,7 +89,7 @@ Debug::Easy - A Handy Debugging Module With Colorized Output and Formatting
  $debug->INFO(       ['Information and VERBOSE mode message']);
  $debug->INFORMATION(['Information and VERBOSE mode message']);
  $debug->DEBUG(      ['Level 1 Debug message']);
- $debug->DEBUGMAX(   ['Level 2 Debug message']);
+ $debug->DEBUGMAX(   ['Level 2 (terse) Debug message']);
 
  my @messages = (
     'First Message',
@@ -122,34 +98,25 @@ Debug::Easy - A Handy Debugging Module With Colorized Output and Formatting
     \%hash_reference
  );
 
- $debug->debug($debug_level,\@messages);
+ $debug->INFO(\@messages);
 
 =head1 DESCRIPTION
 
-This module makes it easy to add debugging features to your code,
-Without having to re-invent the wheel.  It uses STDERR and ANSI color
-Formatted text output, as well as indented and multiline text
-formatting, to make things easy to read.  NOTE:  It is generally
-defaulted to output in a format for viewing on wide terminals!
+This module makes it easy to add debugging features to your code, Without having to re-invent the wheel.  It uses STDERR and ANSI color formatted text output, as well as indented and multiline text formatting, to make things easy to read.  NOTE:  It is generally defaulted to output in a format for viewing on wide terminals!
 
-Benchmarking is automatic, to make it easy to spot bottlenecks in code.
-It automatically stamps from where it was called, and makes debug
-coding so much easier, without having to include the location of the
-debugging location in your debug message.  This is all taken care of
-for you.
+Benchmarking is automatic, to make it easy to spot bottlenecks in code.  It automatically stamps from where it was called, and makes debug coding so much easier, without having to include the location of the debugging location in your debug message.  This is all taken care of for you.
 
-It also allows multiple output levels from errors only, to
-warnings, to notices, to verbose information, to full on debug output.
-All of this fully controllable by the coder.
+It also allows multiple output levels from errors only, to warnings, to notices, to verbose information, to full on debug output.  All of this fully controllable by the coder.
 
-It is essentially a smart wrapper on top of Log::Fast to enhance it.
+It is essentially a smart wrapper on top of Log::Fast to enhance it. ** See AUTHOR COMMENTS near the end of this document.
 
-=head1 EXPORTABLE VARIABLES
+Generally all you need are the defaults and you are ready to go.
 
-=head2 @Levels
+=head1 B<EXPORTABLE VARIABLES>
 
- A simple list of all the acceptable debug levels to pass to the {debug} method,
- and the {new} method.
+=head2 B<@Levels>
+
+ A simple list of all the acceptable debug levels to pass as "LogLevel" in the {new} method.  Not normally needed for coding, more for reference.  Only exported if requested.
 
 =cut
 
@@ -160,93 +127,71 @@ END {    # We spit out one last message before we die, the total execute time.
     $LOG->DEBUG(' %s%s %s', $bench, $ANSILevel{'DEBUG'}, colored(['black on_white'], "---- $name complete ----")) if (defined($ANSILevel{'DEBUG'}) && defined($LOG));
 } ## end END
 
-=head1 METHODS
+=head1 B<METHODS>
 
-=head2 new
+=head2 B<new>
 
 The parameter names are case insensitive as of Version 0.04.
 
-=over 2
+=over 4
 
 =item B<LogLevel> [level]
 
-This adjusts the global log level of the Debug object.  It requires
-a string.
+This adjusts the global log level of the Debug object.  It requires a string.
+
+=back
+
+=over 8
+
+B<ERR> (default)
+
+ This level shows only error messages and all other messages are not shown.
+
+B<WARN>
+
+ This level shows error and warning messages.  All other messages are not shown.
+
+B<NOTICE>
+
+ This level shows error, warning, and notice messages.  All other messages are not shown.
+
+B<INFO>
+
+ This level shows error, warning, notice, and information messages.  Only debug level messages are not shown.
+
+B<VERBOSE>
+
+ This level can be used as a way to do "Verbose" output for your scripts.  It ouputs INFO level messages without logging headers and on STDOUT instead of STDERR.
+
+B<DEBUG>
+
+ This level shows error, warning, notice, information, and level 1 debugging messages.  Level 2 Debug messages are not shown.
+
+B<DEBUGMAX>
+
+ This level shows all messages up to level 2 debugging messages.
+
+ NOTE:  It has been asked "Why have two debugging levels?"  Well, I have had many times where I would like to see what a script is doing without it showing what I consider garbage overhead it may generate.  This is simply because the part of the code you are debugging you may not need such a high level of detail.  I use 'DEBUGMAX' to show me absolutely everything.  Such as Data::Dumper output.  Besides, anyone asking that question obviously hasn't dealt with complex data conversion scripts.
 
 =back
 
 =over 4
 
-=item C<ERR> (default)
+=item B<Color> [boolean] (Not case sensitive)
 
-This level shows only error messages and all other messages are not
-shown.
+B<0>, B<Off>, or B<False> (Off)
 
-=item C<WARN>
+  This turns off colored output.  Everything is plain text only.
 
-This level shows error and warning messages.  All other messages are
-not shown.
+B<1>, B<On>, or B<True> (On - Default)
 
-=item C<NOTICE>
-
-This level shows error, warning, and notice messages.  All other
-messages are not shown.
-
-=item C<INFO>
-
-This level shows error, warning, notice, and information messages.
-Only debug level messages are not shown.
-
-=item C<VERBOSE>
-
-This level can be used as a way to do "Verbose" output for your
-scripts.  It ouputs INFO level messages without logging headers
-and on STDOUT instead of STDERR.
-
-NOTE:  A question was asked why this uses STDOUT.  The answer is
-simple, I have never run across a script that sent "verbose"
-output on STDERR.  If you don't like this behavior, then just use
-the 'INFO' log level instead of 'VERBOSE'.
-
-=item C<DEBUG>
-
-This level shows error, warning, notice, information, and level 1
-debugging messages.  Level 2 Debug messages are not shown.
-
-=item C<DEBUGMAX>
-
-This level shows all messages up to level 2 debugging messages.
-
-NOTE:  It has been asked "Why have two debugging levels?"  Well,
-I have had many times where I would like to see what a script is
-doing without it showing what I consider garbage overhead it may
-generate.  This is simply because the part of the code you are
-debugging you may not need such a high level of detail.  I use
-'DEBUGMAX' to show me absolutely everything.  Such as Data::Dumper
-output.
-
-=item C<Color> [boolean] (Not case sensitive)
+  This turns on colored output.  This makes it easier to spot all of the different types of messages throughout a sea of debug output.  You can read the output with Less, and see color, by using it's switch "-r".
 
 =back
 
-=over 6
+=over 4
 
-=item C<0>, C<Off>, or C<False> (Off)
-
- This turns off colored output.  Everything is plain text only.
-
-=item C<1>, C<On>, or C<True> (On - Default)
-
- This turns on colored output.  This makes it easier to spot all of
- the different types of messages throughout a sea of debug output.
- You can read the output with Less, and see color, by using it's
- switch "-r".
-
-=back
-
-=over 2
-
-=item C<Prefix> [pattern]
+=item B<Prefix> [pattern]
 
 This is global
 
@@ -270,7 +215,7 @@ DEFAULT:  '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] '
      P = Parent
      C = Child
 
-=item C<[loglevel]-Prefix> [pattern]
+=item B<[loglevel]-Prefix> [pattern]
 
 You can define a prefix for a specific log level.
 
@@ -283,7 +228,7 @@ You can define a prefix for a specific log level.
 
 If one of these are not defined, then the global value is used.
 
-=item C<TimeStamp> [pattern]
+=item B<TimeStamp> [pattern]
 
 (See Log::Fast for specifics on these)
 
@@ -293,26 +238,23 @@ Make this an empty string to turn it off, otherwise:
 
 =back
 
-=over 4
+=over 8
 
-=item C<%T>
+B<%T>
 
- Formats the timestamp as HH:MM:SS.  This is the default for the
- timestamp.
+ Formats the timestamp as HH:MM:SS.  This is the default for the timestamp.
 
-=item C<%S>
+B<%S>
 
- Formats the timestamp as seconds.milliseconds.  Normally not needed,
- as the benchmark is more helpful.
+ Formats the timestamp as seconds.milliseconds.  Normally not needed, as the benchmark is more helpful.
 
-=item C<%T %S>
+B<%T %S>
 
- Combines both of the above.  Normally this is just too much, but here
- if you really want it.
+ Combines both of the above.  Normally this is just too much, but here if you really want it.
 
 =back
 
-=over 2
+=over 4
 
 =item B<DateStamp> [pattern]
 
@@ -324,40 +266,36 @@ Make this an empty string to turn it off, otherwise:
 
 =back
 
-=over 4
+=over 8
 
-=item C<%D>
+B<%D>
 
- Formats the datestamp as YYYY-MM-DD.  It is the default, and the only
- option.
+ Formats the datestamp as YYYY-MM-DD.  It is the default, and the only option.
 
 =back
 
-=over 2
+=over 4
 
 =item B<Type>
 
- Output type. Possible values are: 'fh' (output to any already open
- filehandle) and 'unix' (output to syslog using UNIX socket).
+ Output type. Possible values are: 'fh' (output to any already open filehandle) and 'unix' (output to syslog using UNIX socket).
+
+=back
+
+=over 8
+
+B<fh>
+
+ When set to 'fh', you have to also set {FileHandle} to any open filehandle (like "\*STDERR", which is the default).
+
+B<unix>
+
+ When set to 'unix', you have to also set {FileHandle} to a path pointing to an existing unix socket (typically it's '/dev/log').
 
 =back
 
 =over 4
 
-=item C<fh>
-
- When set to 'fh', you have to also set {FileHandle} to any open filehandle
- (like "\*STDERR", which is the default).
-
-=item C<unix>
-
- When set to 'unix', you have to also set {FileHandle} to a path pointing to an
- existing unix socket (typically it's '/dev/log').
-
-=back
-
-=over 2
-
 =item B<FileHandle>
 
  File handle to write log messages if {Type} set to 'fh' (which is the default).
@@ -372,7 +310,7 @@ Make this an empty string to turn it off, otherwise:
 
 =back
 
-=over 4
+=over 8
 
   'ANSILevel' => {
      'ERR'       => colored(['white on_red'],       '[ ERROR ]'),
@@ -429,6 +367,7 @@ sub new {
         },
         @_
     };
+    # This pretty much makes all hash keys uppercase
     my @Keys = (keys %{$self});
     foreach my $Key (@Keys) {
         my $upper = uc($Key);
@@ -463,7 +402,7 @@ sub new {
     %ANSILevel = %{$self->{'ANSILEVEL'}};
 
     foreach my $lvl (@Levels) {
-        $self->{"$lvl-PREFIX"} = $self->{'PREFIX'} unless (defined($self->{"$lvl-PREFIX"}));
+        $self->{"$lvl-PREFIX"} = $self->{'PREFIX'} unless (exists($self->{"$lvl-PREFIX"}) && defined($self->{"$lvl-PREFIX"}));
     }
 
     # The Global loglevel is set here.
@@ -494,15 +433,17 @@ sub new {
 
 =head2 debug
 
+NOTE:  This is a legacy method for backwards compatibility.  Please use the direct methods instead.
+
 The parameters must be passed in the order given
 
-=over 2
+=over 4
 
-=item C<LEVEL>
+=item B<LEVEL>
 
  The log level with which this message is to be triggered
 
-=item C<MESSAGE(S)>
+=item B<MESSAGE(S)>
 
  A string or a reference to a list of strings to output line by line.
 
@@ -665,14 +606,13 @@ sub _send_to_logger {      # This actually simplifies the previous object ... se
     }
 } ## end sub _send_to_logger
 
-=head2 ERR
+=head2 b<ERR> or B<ERROR>
 
-This is a friendlier wrapper to 'debug('ERR',['message'])'.  The level is
-inferred by its name.
+Sends ERROR level debugging output to the log.  Errors are always shown.
 
-=over 2
+=over 4
 
-=item C<MESSAGE>
+=item B<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -684,31 +624,18 @@ sub ERR {
     $self->debug('ERR', @_);
 }
 
-=head2 ERROR
-
-This is a friendlier wrapper to 'debug('ERR',['message'])'.  The level is inferred by its name.
-
-=over 2
-
-=item C<MESSAGE>
-
-Either a single string or a reference to a list of strings
-
-=back
-=cut
-
 sub ERROR {
     my $self = shift;
     $self->debug('ERR', @_);
 }
 
-=head2 WARN
+=head2 B<WARN> or B<WARNING>
 
-This is a friendlier wrapper to 'debug('WARN',['message'])'.  The level is inferred by its name.
+If the log level is WARN or above, then these warnings are logged.
 
-=over 2
+=over 4
 
-=item C<MESSAGE>
+=item B<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -720,31 +647,18 @@ sub WARN {
     $self->debug('WARN', @_);
 }
 
-=head2 WARNING
-
-This is a friendlier wrapper to 'debug('WARN',['message'])'.  The level is inferred by its name.
-
-=over 2
-
-=item C<MESSAGE>
-
-Either a single string or a reference to a list of strings
-
-=back
-=cut
-
 sub WARNING {
     my $self = shift;
     $self->debug('WARN', @_);
 }
 
-=head2 NOTICE
+=head2 B<NOTICE>
 
-This is a friendlier wrapper to 'debug('NOTICE',['message'])'.  The level is inferred by its name.
+If the loglevel is NOTICE or above, then these notices are logged.
 
-=over 2
+=over 4
 
-=item C<MESSAGE>
+=item B<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -756,13 +670,13 @@ sub NOTICE {
     $self->debug('NOTICE', @_);
 }
 
-=head2 INFO
+=head2 B<INFO> or B<INFORMATION>
 
-This is a friendlier wrapper to 'debug('INFO',['message'])'.  The level is inferred by its name.
+If the loglevel is INFO (or VERBOSE) or above, then these information messages are displayed.
 
-=over 2
+=over 4
 
-=item C<MESSAGE>
+=item B<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -774,31 +688,18 @@ sub INFO {
     $self->debug('INFO', @_);
 }
 
-=head2 INFORMATION
-
-This is a friendlier wrapper to 'debug('INFO',['message'])'.  The level is inferred by its name.
-
-=over 2
-
-=item C<MESSAGE>
-
-Either a single string or a reference to a list of strings
-
-=back
-=cut
-
 sub INFORMATION {
     my $self = shift;
     $self->debug('INFO', @_);
 }
 
-=head2 DEBUG
+=head2 B<DEBUG>
 
-This is a friendlier wrapper to 'debug('DEBUG',['message'])'.  The level is inferred by its name.
+If the Loglevel is DEBUG or above, then basic debugging messages are logged.  DEBUG is intended for basic program flow messages for easy tracing.  Best not to place variable contents in these messages.
 
-=over 2
+=over 4
 
-=item C<MESSAGE>
+=item B<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -810,13 +711,13 @@ sub DEBUG {
     $self->debug('DEBUG', @_);
 }
 
-=head2 DEBUGMAX
+=head2 B<DEBUGMAX>
 
-This is a friendlier wrapper to 'debug('DEBUGMAX',['message'])'.  The level is inferred by its name.
+If the loglevel is DEBUGMAX, then all messages are shown, and terse debugging messages as well.  Typically DEBUGMAX is used for variable dumps and detailed data output for heavy tracing.  This is a very "noisy" log level.
 
-=over 2
+=over 4
 
-=item C<MESSAGE>
+=item B<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -830,16 +731,15 @@ sub DEBUGMAX {
 
 1;
 
-=head1 CAVEATS
+=head1 B<CAVEATS>
 
-Since it is possible to duplicate the object in a fork or thread, the output
-formatting may be mismatched between forks and threads due to the automatic
-padding adjustment of the subroutine name field.
+Since it is possible to duplicate the object in a fork or thread, the output formatting may be mismatched between forks and threads due to the automatic padding adjustment of the subroutine name field.
 
-The "less" pager is the best for viewing log files generated by this module.
-It's switch "-r" allows you to see them in all their colorful glory.
+Ways around this are to separately create a Debug::Easy object in each fork or thread, and have them log to separate files.
 
-=head1 INSTALLATION
+The "less" pager is the best for viewing log files generated by this module.  It's switch "-r" allows you to see them in all their colorful glory.
+
+=head1 B<INSTALLATION>
 
 To install this module, run the following commands:
 
@@ -861,24 +761,21 @@ Richard Kelsch <rich@rk-internet.com>
 
 Copyright 2013 Richard Kelsch, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-=head1 VERSION
+=head1 B<VERSION>
 
-Version 1.08    (September 11, 2015)
+Version 1.11    (February 10, 2016)
 
-=head1 BUGS
+=head1 B<BUGS>
 
-Please report any bugs or feature requests to C<bug-easydebug at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=EasyDebug>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-easydebug at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=EasyDebug>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
-=head1 SUPPORT
+=head1 B<SUPPORT>
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Debug::Easy
+C<perldoc Debug::Easy>
 
 
 You can also look for information at:
@@ -897,57 +794,48 @@ L<http://annocpan.org/dist/Debug-Easy>
 
 L<http://cpanratings.perl.org/d/Debug-Easy>
 
+Not exactly a reliable and fair means of rating modules.  Modules are updated and improved over time, and what may have been a poor or mediocre review at version 0,04, may not remotely apply to current or later versions.  It applies ratings in an arbitrary manner with no ability for the author to add their own rebuttals or comments to the review, especially should the review be malicious or inapplicable.
+
+More importantly, issues brought up in a mediocre review may have been addressed and improved in later versions, or completely changed to allieviate that issue.
+
+So, check the reviews AND the version number when that review was written.
+
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/Debug-Easy/>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
+=head1 B<ACKNOWLEDGEMENTS>
 
-The author of Log::Fast.  A very fine module, without which, this module
-would be much larger.
+The author of Log::Fast.  A very fine module, without which, this module would be much larger.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 B<AUTHOR COMMENTS>
+
+Earlier versions of this module (pre version 1.0), were difficult to code with, and not "Easy" as the name implied.  Version 1.x+ has addressed the issues brought forward by some users (and reviewers), and has made the module truely easy to use.
+
+Version 2.0 promises to be even simpler, with fewer prerequisites on installation.  Specifically the requirement for "Log::Fast" will be removed, and this module will exclusively handle logging, as I believe it should.
+
+I coded this module because it filled a gap when I was working for a major chip manufacturing company.  It gave the necessary output the other coders asked for, and fulfilled a need.  It has grown far beyond those days, and I use it every day in my coding work.
+
+If you have any features you wish added, or functionality improved or changed, then I welcome them, and will very likely incorporate them sooner than you think.
+
+=head1 B<LICENSE AND COPYRIGHT>
 
 Copyright 2013 Richard Kelsch.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+This program is free software; you can redistribute it and/or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
 
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
+Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License. By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license.
 
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
+If your Modified Version has been derived from a Modified Version made by someone other than you, you are nevertheless required to ensure that your Modified Version complies with the requirements of this license.
 
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
+This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder.
 
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement, then this Artistic License to you shall terminate on the date that such litigation is filed.
 
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
-
